@@ -18,17 +18,18 @@ function(x, ...){
   #  cat(" seconds.\n")
   #}
   if(x$method=="gibbs"){
-    cat("\nAmong the visited models, the Highest posterior probability model is: \n")
-    print(x$modelsprob)
+    cat("\nAmong the visited models, the model with the largest probability contains: \n")
+    print(names(which(x$HPMbin==1)))
   }
   if(x$method!="gibbs"){
-    if(n.keep<10){
-      cat(paste("\nThe",pp,"most probable models and their probabilities are:\n",sep=" "))
+    if(n.keep<=10){
+      cat(paste("\nThe",n.keep,"most probable models and their probabilities are:\n",sep=" "))
       print(x$modelsprob)
     }
-    if(n.keep>=10){
+    if(n.keep>10){
       cat("\nThe 10 most probable models and their probabilities are:\n")
       print(x$modelsprob[1:10,])
+      cat("\n(The remanining", n.keep-10, "models are kept but omitted in this print)")
     }
   }
    cat("\n")
